==============
arkesel_python
==============


.. image:: https://img.shields.io/pypi/v/arkesel_python.svg
        :target: https://pypi.python.org/pypi/arkesel_python

.. image:: https://img.shields.io/travis/wilham-lynce/arkesel_python.svg
        :target: https://travis-ci.com/wilham-lynce/arkesel_python

.. image:: https://readthedocs.org/projects/arkesel-python/badge/?version=latest
        :target: https://arkesel-python.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




Python Library for the Arkesel API 


* Free software: MIT license
* Documentation: https://arkesel-python.readthedocs.io.


Arkesel API Python Library 
----------------------------

A Python library for the Arkesel API. Allows you to do anything the Arkesel API does, but from within Python apps – send bulk messages , send OTP for phone-number/users authentication, creating and adding contacts to yout groups etc.

Documentation
---------------

* The documentation for the Arkesel API can be found `here <https://developers.arkesel.com>`_ 
* The documentation for the Arkesel Python library documentation can be found `here <https://arkesel-python.readthedocs.io>`__


